@@ -5,7 +5,7 @@ use warnings;
 use base qw(Exporter);
 our @EXPORT = qw(eval yaml);
 
-our $VERSION = '0.60'; # VERSION
+our $VERSION = '0.64'; # VERSION
 
 # eval
 sub eval {
@@ -14,7 +14,7 @@ sub eval {
     command => "eval",
     eval    => $eval,
   });
-  return wantarray ? ( $response->{eval}, $response->{exception} ) :  ##  no critic (Freenode::Wantarray)
+  return wantarray ? ( $response->{eval}, $response->{exception} ) :  ##  no critic (Community::Wantarray)
                      $response->{eval};
 }
 
@@ -42,7 +42,7 @@ Devel::ebug::Plugin::Eval
 
 =head1 VERSION
 
-version 0.60
+version 0.64
 
 =head1 AUTHOR
 
@@ -58,7 +58,7 @@ Taisuke Yamada
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2005-2020 by Leon Brocard.
+This software is copyright (c) 2005-2021 by Leon Brocard.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
